@@ -23,9 +23,12 @@ my $select = Data::HTML::Element::Select->new(
         'css_class' => 'form-select',
 );
 
+# Initialize.
+$obj->init($select);
+
 # Process select.
-$obj->process($select);
-$obj->process_css($select);
+$obj->process;
+$obj->process_css;
 
 # Print out.
 print "HTML:\n";
@@ -36,7 +39,7 @@ print $css->flush;
 
 # Output:
 # HTML:
-# <select class="form-select" type="text" />
+# <select class="form-select" />
 #
 # CSS:
 # select.form-select {
